@@ -4,14 +4,17 @@
 """
 
 
-def print_lol(the_list):
+def print_lol(the_list, level=0):
     """
     在这个函数取一个位置参数，名为"the_list"，
     这可以是任何Python列表（也可以是包含嵌套列表的列表）。
     所指定的列表中的每个数据项会（递归地）输出到屏幕上，各数据项各占一行。
+    第二个参数(名为level)用来在遇到嵌套列表时插入制表符。
     """
     for each_item in the_list:
         if isinstance(each_item, list):
-            print_lol(each_item)
+            print_lol(each_item, level+1)
         else:
+            for num in range(level):
+                print("\t", end="")
             print(each_item)
